import iam = require('@aws-cdk/aws-iam');
import { Construct, IResource, Resource } from '@aws-cdk/cdk';
import { ContainerDefinition, ContainerDefinitionOptions } from '../container-definition';
import { PlacementConstraint } from '../placement';
export interface ITaskDefinition extends IResource {
    /**
     * ARN of this task definition
     * @attribute
     */
    readonly taskDefinitionArn: string;
    /**
     * Execution role for this task definition
     */
    readonly executionRole?: iam.IRole;
    /**
     * What launch types this task definition should be compatible with.
     */
    readonly compatibility: Compatibility;
    /**
     * Return true if the task definition can be run on an EC2 cluster
     */
    readonly isEc2Compatible: boolean;
    /**
     * Return true if the task definition can be run on a Fargate cluster
     */
    readonly isFargateCompatible: boolean;
}
/**
 * Properties common to all Task definitions
 */
export interface CommonTaskDefinitionProps {
    /**
     * Namespace for task definition versions
     *
     * @default - Automatically generated name.
     */
    readonly family?: string;
    /**
     * The IAM role assumed by the ECS agent.
     *
     * The role will be used to retrieve container images from ECR and
     * create CloudWatch log groups.
     *
     * @default - An execution role will be automatically created if you use ECR images in your task definition.
     */
    readonly executionRole?: iam.IRole;
    /**
     * The IAM role assumable by your application code running inside the container
     *
     * @default - A task role is automatically created for you.
     */
    readonly taskRole?: iam.IRole;
    /**
     * See: https://docs.aws.amazon.com/AmazonECS/latest/developerguide//task_definition_parameters.html#volumes
     *
     * @default - No volumes are passed to the Docker daemon on a container instance.
     */
    readonly volumes?: Volume[];
}
/**
 * Properties for generic task definitions
 */
export interface TaskDefinitionProps extends CommonTaskDefinitionProps {
    /**
     * The Docker networking mode to use for the containers in the task.
     *
     * On Fargate, the only supported networking mode is AwsVpc.
     *
     * @default - NetworkMode.Bridge for EC2 tasks, AwsVpc for Fargate tasks.
     */
    readonly networkMode?: NetworkMode;
    /**
     * An array of placement constraint objects to use for the task. You can
     * specify a maximum of 10 constraints per task (this limit includes
     * constraints in the task definition and those specified at run time).
     *
     * Not supported in Fargate.
     *
     * @default - No placement constraints.
     */
    readonly placementConstraints?: PlacementConstraint[];
    /**
     * What launch types this task definition should be compatible with.
     */
    readonly compatibility: Compatibility;
    /**
     * The number of cpu units used by the task.
     *
     * Optional for EC2 tasks and any value can be used.
     *
     * Required for Fargate tasks
     * Valid values, which determines your range of valid values for the memory parameter:
     * 256 (.25 vCPU) - Available memory values: 0.5GB, 1GB, 2GB
     * 512 (.5 vCPU) - Available memory values: 1GB, 2GB, 3GB, 4GB
     * 1024 (1 vCPU) - Available memory values: 2GB, 3GB, 4GB, 5GB, 6GB, 7GB, 8GB
     * 2048 (2 vCPU) - Available memory values: Between 4GB and 16GB in 1GB increments
     * 4096 (4 vCPU) - Available memory values: Between 8GB and 30GB in 1GB increments
     *
     * @default - CPU units are not specified.
     */
    readonly cpu?: string;
    /**
     * The amount (in MiB) of memory used by the task.
     *
     * Optional for EC2 tasks and any value can be used.
     *
     * Required for Fargate tasks
     * This field is required and you must use one of the following values, which determines your range of valid values
     * for the cpu parameter:
     *
     * 0.5GB, 1GB, 2GB - Available cpu values: 256 (.25 vCPU)
     *
     * 1GB, 2GB, 3GB, 4GB - Available cpu values: 512 (.5 vCPU)
     *
     * 2GB, 3GB, 4GB, 5GB, 6GB, 7GB, 8GB - Available cpu values: 1024 (1 vCPU)
     *
     * Between 4GB and 16GB in 1GB increments - Available cpu values: 2048 (2 vCPU)
     *
     * Between 8GB and 30GB in 1GB increments - Available cpu values: 4096 (4 vCPU)
     *
     * @default - Memory used by task is not specified.
     */
    readonly memoryMiB?: string;
}
declare abstract class TaskDefinitionBase extends Resource implements ITaskDefinition {
    abstract readonly compatibility: Compatibility;
    abstract readonly taskDefinitionArn: string;
    abstract readonly executionRole?: iam.IRole;
    /**
     * Return true if the task definition can be run on an EC2 cluster
     */
    readonly isEc2Compatible: boolean;
    /**
     * Return true if the task definition can be run on a Fargate cluster
     */
    readonly isFargateCompatible: boolean;
}
/**
 * Base class for Ecs and Fargate task definitions
 */
export declare class TaskDefinition extends TaskDefinitionBase {
    /**
     * Imports a task definition by ARN.
     *
     * The task will have a compatibility of EC2+Fargate.
     */
    static fromTaskDefinitionArn(scope: Construct, id: string, taskDefinitionArn: string): ITaskDefinition;
    /**
     * The family name of this task definition
     */
    readonly family: string;
    /**
     * ARN of this task definition
     * @attribute
     */
    readonly taskDefinitionArn: string;
    /**
     * Task role used by this task definition
     */
    readonly taskRole: iam.IRole;
    /**
     * Network mode used by this task definition
     */
    readonly networkMode: NetworkMode;
    /**
     * Default container for this task
     *
     * Load balancers will send traffic to this container. The first
     * essential container that is added to this task will become the default
     * container.
     */
    defaultContainer?: ContainerDefinition;
    /**
     * What launching modes this task is compatible with
     */
    readonly compatibility: Compatibility;
    /**
     * All containers
     */
    protected readonly containers: ContainerDefinition[];
    /**
     * All volumes
     */
    private readonly volumes;
    /**
     * Placement constraints for task instances
     */
    private readonly placementConstraints;
    private _executionRole?;
    constructor(scope: Construct, id: string, props: TaskDefinitionProps);
    readonly executionRole: iam.IRole | undefined;
    /**
     * Add a policy statement to the Task Role
     */
    addToTaskRolePolicy(statement: iam.PolicyStatement): void;
    /**
     * Add a policy statement to the Execution Role
     */
    addToExecutionRolePolicy(statement: iam.PolicyStatement): void;
    /**
     * Create a new container to this task definition
     */
    addContainer(id: string, props: ContainerDefinitionOptions): ContainerDefinition;
    /**
     * Add a volume to this task definition
     */
    addVolume(volume: Volume): void;
    /**
     * Constrain where tasks can be placed
     */
    addPlacementConstraint(constraint: PlacementConstraint): void;
    /**
     * Extend this TaskDefinition with the given extension
     *
     * Extension can be used to apply a packaged modification to
     * a task definition.
     */
    addExtension(extension: ITaskDefinitionExtension): void;
    /**
     * Create the execution role if it doesn't exist
     */
    obtainExecutionRole(): iam.IRole;
    /**
     * Validate this task definition
     */
    protected validate(): string[];
}
/**
 * The Docker networking mode to use for the containers in the task.
 */
export declare enum NetworkMode {
    /**
     * The task's containers do not have external connectivity and port mappings can't be specified in the container definition.
     */
    None = "none",
    /**
     * The task utilizes Docker's built-in virtual network which runs inside each container instance.
     */
    Bridge = "bridge",
    /**
     * The task is allocated an elastic network interface.
     */
    AwsVpc = "awsvpc",
    /**
     * The task bypasses Docker's built-in virtual network and maps container ports directly to the EC2 instance's network interface directly.
     *
     * In this mode, you can't run multiple instantiations of the same task on a
     * single container instance when port mappings are used.
     */
    Host = "host"
}
/**
 * Volume definition
 */
export interface Volume {
    /**
     * Path on the host
     */
    readonly host?: Host;
    /**
     * A name for the volume
     */
    readonly name: string;
    /**
     * Specifies this configuration when using Docker volumes
     */
    readonly dockerVolumeConfiguration?: DockerVolumeConfiguration;
}
/**
 * A volume host
 */
export interface Host {
    /**
     * Source path on the host
     */
    readonly sourcePath?: string;
}
/**
 * A configuration of a Docker volume
 */
export interface DockerVolumeConfiguration {
    /**
     * If true, the Docker volume is created if it does not already exist
     *
     * @default false
     */
    readonly autoprovision?: boolean;
    /**
     * The Docker volume driver to use
     */
    readonly driver: string;
    /**
     * A map of Docker driver specific options passed through
     *
     * @default No options
     */
    readonly driverOpts?: string[];
    /**
     * Custom metadata to add to your Docker volume
     *
     * @default No labels
     */
    readonly labels?: string[];
    /**
     * The scope for the Docker volume which determines it's lifecycle
     */
    readonly scope: Scope;
}
export declare enum Scope {
    /**
     * Docker volumes are automatically provisioned when the task starts and destroyed when the task stops
     */
    Task = "task",
    /**
     * Docker volumes are persist after the task stops
     */
    Shared = "shared"
}
/**
 * Task compatibility
 */
export declare enum Compatibility {
    /**
     * Task should be launchable on EC2 clusters
     */
    Ec2 = 0,
    /**
     * Task should be launchable on Fargate clusters
     */
    Fargate = 1,
    /**
     * Task should be launchable on both types of clusters
     */
    Ec2AndFargate = 2
}
/**
 * An extension for Task Definitions
 *
 * Classes that want to make changes to a TaskDefinition (such as
 * adding helper containers) can implement this interface, and can
 * then be "added" to a TaskDefinition like so:
 *
 *    taskDefinition.addExtension(new MyExtension("some_parameter"));
 */
export interface ITaskDefinitionExtension {
    /**
     * Apply the extension to the given TaskDefinition
     *
     * @param taskDefinition [disable-awslint:ref-via-interface]
     */
    extend(taskDefinition: TaskDefinition): void;
}
export {};
