import ec2 = require('@aws-cdk/aws-ec2');
import elb = require('@aws-cdk/aws-elasticloadbalancing');
import { Construct } from '@aws-cdk/cdk';
import { BaseService, BaseServiceProps, IService } from '../base/base-service';
import { TaskDefinition } from '../base/task-definition';
import { BinPackResource, PlacementConstraint, PlacementStrategy } from '../placement';
/**
 * Properties to define an ECS service
 */
export interface Ec2ServiceProps extends BaseServiceProps {
    /**
     * Task Definition used for running tasks in the service
     *
     * [disable-awslint:ref-via-interface]
     */
    readonly taskDefinition: TaskDefinition;
    /**
     * Assign public IP addresses to each task
     *
     * @default - Use subnet default.
     */
    readonly assignPublicIp?: boolean;
    /**
     * In what subnets to place the task's ENIs
     *
     * (Only applicable in case the TaskDefinition is configured for AwsVpc networking)
     *
     * @default - Private subnets.
     */
    readonly vpcSubnets?: ec2.SubnetSelection;
    /**
     * Existing security group to use for the task's ENIs
     *
     * (Only applicable in case the TaskDefinition is configured for AwsVpc networking)
     *
     * @default - A new security group is created.
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * Placement constraints
     *
     * @default - No constraints.
     */
    readonly placementConstraints?: PlacementConstraint[];
    /**
     * Placement strategies
     *
     * @default - No strategies.
     */
    readonly placementStrategies?: PlacementStrategy[];
    /**
     * Deploy exactly one task on each instance in your cluster.
     *
     * When using this strategy, do not specify a desired number of tasks or any
     * task placement strategies.
     *
     * @default false
     */
    readonly daemon?: boolean;
}
export interface IEc2Service extends IService {
}
/**
 * Start a service on an ECS cluster
 *
 * @resource AWS::ECS::Service
 */
export declare class Ec2Service extends BaseService implements IEc2Service, elb.ILoadBalancerTarget {
    static fromEc2ServiceArn(scope: Construct, id: string, ec2ServiceArn: string): IEc2Service;
    /**
     * Name of the cluster
     */
    readonly clusterName: string;
    private readonly constraints;
    private readonly strategies;
    private readonly daemon;
    constructor(scope: Construct, id: string, props: Ec2ServiceProps);
    /**
     * Place tasks only on instances matching the given query expression
     *
     * You can specify multiple expressions in one call. The tasks will only
     * be placed on instances matching all expressions.
     *
     * @see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html
     * @deprecated Use addPlacementConstraints() instead.
     */
    placeOnMemberOf(...expressions: string[]): void;
    /**
     * Try to place tasks spread across instance attributes.
     *
     * You can use one of the built-in attributes found on `BuiltInAttributes`
     * or supply your own custom instance attributes. If more than one attribute
     * is supplied, spreading is done in order.
     *
     * @default attributes instanceId
     * @deprecated Use addPlacementStrategies() instead.
     */
    placeSpreadAcross(...fields: string[]): void;
    /**
     * Try to place tasks on instances with the least amount of indicated resource available
     *
     * This ensures the total consumption of this resource is lowest.
     *
     * @deprecated Use addPlacementStrategies() instead.
     */
    placePackedBy(resource: BinPackResource): void;
    /**
     * Place tasks randomly across the available instances.
     *
     * @deprecated Use addPlacementStrategies() instead.
     */
    placeRandomly(): void;
    /**
     * Add one or more placement strategies
     */
    addPlacementStrategies(...strategies: PlacementStrategy[]): void;
    /**
     * Add one or more placement strategies
     */
    addPlacementConstraints(...constraints: PlacementConstraint[]): void;
    /**
     * Register this service as the target of a Classic Load Balancer
     *
     * Don't call this. Call `loadBalancer.addTarget()` instead.
     */
    attachToClassicLB(loadBalancer: elb.LoadBalancer): void;
    /**
     * Validate this Ec2Service
     */
    protected validate(): string[];
}
/**
 * Built-in container instance attributes
 */
export declare class BuiltInAttributes {
    /**
     * The Instance ID of the instance
     */
    static readonly InstanceId = "instanceId";
    /**
     * The AZ where the instance is running
     */
    static readonly AvailabilityZone = "attribute:ecs.availability-zone";
    /**
     * The AMI ID of the instance
     */
    static readonly AmiId = "attribute:ecs.ami-id";
    /**
     * The instance type
     */
    static readonly InstanceType = "attribute:ecs.instance-type";
    /**
     * The OS type
     *
     * Either 'linux' or 'windows'.
     */
    static readonly OsType = "attribute:ecs.os-type";
}
