import ec2 = require('@aws-cdk/aws-ec2');
import cdk = require('@aws-cdk/cdk');
import { Construct } from '@aws-cdk/cdk';
import { BaseService, BaseServiceProps, IService } from '../base/base-service';
import { TaskDefinition } from '../base/task-definition';
/**
 * Properties to define a Fargate service
 */
export interface FargateServiceProps extends BaseServiceProps {
    /**
     * Task Definition used for running tasks in the service
     *
     * [disable-awslint:ref-via-interface]
     */
    readonly taskDefinition: TaskDefinition;
    /**
     * Assign public IP addresses to each task
     *
     * @default - Use subnet default.
     */
    readonly assignPublicIp?: boolean;
    /**
     * In what subnets to place the task's ENIs
     *
     * @default - Private subnets.
     */
    readonly vpcSubnets?: ec2.SubnetSelection;
    /**
     * Existing security group to use for the tasks
     *
     * @default - A new security group is created.
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * Fargate platform version to run this service on
     *
     * Unless you have specific compatibility requirements, you don't need to
     * specify this.
     *
     * @default Latest
     */
    readonly platformVersion?: FargatePlatformVersion;
}
export interface IFargateService extends IService {
}
/**
 * Start a service on an ECS cluster
 *
 * @resource AWS::ECS::Service
 */
export declare class FargateService extends BaseService implements IFargateService {
    static fromFargateServiceArn(scope: Construct, id: string, fargateServiceArn: string): IFargateService;
    constructor(scope: cdk.Construct, id: string, props: FargateServiceProps);
}
/**
 * Fargate platform version
 *
 * @see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html
 */
export declare enum FargatePlatformVersion {
    /**
     * The latest, recommended platform version
     */
    Latest = "LATEST",
    /**
     * Version 1.3.0
     *
     * Supports secrets, task recycling.
     */
    Version1_3 = "1.3.0",
    /**
     * Version 1.2.0
     *
     * Supports private registries.
     */
    Version1_2 = "1.2.0",
    /**
     * Version 1.1.0
     *
     * Supports task metadata, health checks, service discovery.
     */
    Version1_1 = "1.1.0",
    /**
     * Initial release
     *
     * Based on Amazon Linux 2017.09.
     */
    Version1_0 = "1.0.0"
}
